@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2024 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.com,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 
 # wrapper for Tps object 
 "predict.Tps"<- function(object, ...){
@@ -77,7 +78,7 @@
     #  i.e.   knots <- scale( object$knots, xc, xs)
     #
     # figure out if the coefficients for the surface needto be recomputed.
-    find.coef <- (!is.null(y) | !is.null(yM) | !is.na(lambda) | 
+    find.coef<- (!is.null(y) | !is.null(yM) | !is.na(lambda) | 
         !is.na(df) | !is.na(model[1]))
     if (verbose) {
         cat("find.coef", find.coef, fill = TRUE)
@@ -103,7 +104,7 @@
         temp.c <- object3$c
     }
     if (verbose) {
-        cat(" d coefs", fill = TRUE)
+        cat(" betas", fill = TRUE)
         print(temp.d)
         cat("c coefs", fill = TRUE)
         print(temp.c)
@@ -133,18 +134,6 @@
         temp <- temp + do.call(object$cov.function.name, c(object$args, 
             list(x1 = x, x2 = object$knots, C = temp.c)))
     }
-    #
-    # transform back into raw scale if this is a correlation model.
-    # if y's are in the scale of correlations
-    # if so scale by sd and add back in mean
-    correlation.model <- (object$correlation.model & eval.correlation.model)
-    if (correlation.model) {
-        if (!is.na(object$sd.obj[1])) {
-            temp <- temp * predict(object$sd.obj, x)
-        }
-        if (!is.na(object$mean.obj[1])) {
-            temp <- temp + predict(object$mean.obj, x)
-        }
-    }
+
     return(temp)
 }
